package com.ruoyi.service;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.service.client.HttpClient;
import com.ruoyi.service.constants.SignatureMethod;
import com.ruoyi.service.constants.SignatureVersion;
import com.ruoyi.service.domain.APIRequestDTO;
import com.ruoyi.service.domain.AuthInfo;
import com.ruoyi.service.utils.HttpUtils;
import com.ruoyi.service.utils.IdentifyTools;
import okhttp3.Request;
import okhttp3.Response;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ServiceSdk {
    private static final Logger logger = LoggerFactory.getLogger(com.ruoyi.service.ServiceSdk.class);

    public ServiceSdk() {
    }

    public static String invoke(String url, APIRequestDTO request, String userId, String subServiceId, String applicationId, String accessToken) throws Exception {
        logger.info("start request data");
        AuthInfo auth = new AuthInfo(userId, SignatureVersion.VERSION2.getCode(), "UTF-8");
        String signatureMethod = (SignatureVersion.VERSION2.getCode().equals(auth.getSignatureVersion()) ? SignatureMethod.HmacSHA256 : SignatureMethod.HmacSHA1).getCode();
        String signStr = IdentifyTools.sign(JSONObject.toJSONString(auth), accessToken, signatureMethod, auth.getEncoding());
        auth.setSignature(signStr);
        request.setAuthInfo(auth);
        request.setApplicationId(applicationId);
        request.setSubServiceId(subServiceId);
        Request httpRequest = HttpUtils.createHttpRequest(url, JSON.toJSONString(request));
        Response response = HttpClient.getInstance().getClient().newCall(httpRequest).execute();
        logger.info("request data finished");
        return HttpUtils.readBody(response);
    }
}

