package com.ruoyi.service.client;


import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.URL;
import java.util.Properties;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class HttpConfig {
    private static final Logger LOG = LoggerFactory.getLogger(com.ruoyi.service.client.HttpConfig.class);
    private static final String ES_CONFIG_FILE = "httpclient.properties";
    private static int connectTimeoutSeconds = 30;
    private static int readTimeoutSeconds = 30;
    private static int writeTimeoutSeconds = 30;
    private static int maxConnections = 10;
    private static int connKeepaliveMinute = 5;

    public HttpConfig() {
    }

    public static Properties readProperties(String fileName) throws Exception {
        Properties properties = new Properties();

        try {
            boolean flag = true;
            String configPath = System.getProperty("user.dir") + File.separator + "conf" + File.separator + fileName;
            File file = new File(configPath);
            if (flag && file.exists()) {
                properties.load(new FileInputStream(file));
                flag = false;
            }

            if (flag) {
                URL url = Thread.currentThread().getContextClassLoader().getResource("");
                String path = url.getPath().replace("classes", "conf") + fileName;
                file = new File(path);
                if (file.exists()) {
                    properties.load(new FileInputStream(file));
                    flag = false;
                }
            }

            if (flag) {
                InputStream inputStream = com.ruoyi.service.client.HttpConfig.class.getClassLoader().getResourceAsStream(fileName);
                if (null != inputStream) {
                    properties.load(inputStream);
                }
            }

            return properties;
        } catch (Exception var7) {
            Exception e = var7;
            LOG.error("Read config properties error,file=" + fileName, e);
            throw e;
        }
    }

    public static int connectTimeoutSeconds() {
        return connectTimeoutSeconds;
    }

    public static int readTimeoutSeconds() {
        return readTimeoutSeconds;
    }

    public static int writeTimeoutSeconds() {
        return writeTimeoutSeconds;
    }

    public static int maxConnections() {
        return maxConnections;
    }

    public static int connKeepaliveMinute() {
        return connKeepaliveMinute;
    }

    static {
        try {
            Properties properties = readProperties("httpclient.properties");
            if (null != properties && !properties.isEmpty()) {
                connectTimeoutSeconds = Integer.parseInt(properties.getProperty("connect.timeout.seconds"));
                readTimeoutSeconds = Integer.parseInt(properties.getProperty("read.timeout.seconds"));
                writeTimeoutSeconds = Integer.parseInt(properties.getProperty("write.timeout.seconds"));
                maxConnections = Integer.parseInt(properties.getProperty("max.connections"));
                connKeepaliveMinute = Integer.parseInt(properties.getProperty("connection.keep.alive.minutes"));
            }

            LOG.info("connectTimeoutSeconds:" + connectTimeoutSeconds);
            LOG.info("readTimeoutSeconds:" + readTimeoutSeconds);
            LOG.info("writeTimeoutSeconds:" + writeTimeoutSeconds);
            LOG.info("maxConnections:" + maxConnections);
            LOG.info("connKeepaliveMinute:" + connKeepaliveMinute);
        } catch (Exception var1) {
            Exception e = var1;
            LOG.error("Failed to load properties file conf/httpclient.properties", e);
        }

    }
}
